@@ -7,7 +7,7 @@ use warnings;
 
 use parent 'Data::Object::Config';
 
-our $VERSION = '1.85'; # VERSION
+our $VERSION = '1.86'; # VERSION
 
 # METHODS
 
@@ -125,9 +125,9 @@ foundational set of types, functions, classes, patterns, and interfaces for
 jump-starting application development. This package inherits all behavior from
 L<Data::Object::Config>, and offers the same functionality as the L<Do>
 package. Please see that documentation to learn more, or get started quickly by
-reviewing the L<"basic usage"|/convention> and L<"configurations"|/framework>,
-or the L<overview|https://github.com/iamalnewkirk/do/blob/master/OVERVIEW.md>
-and project L<wiki|https://github.com/iamalnewkirk/do/wiki>.
+reviewing L<basic usage|/CONVENTION>, L<configurations|/FRAMEWORK>, the
+L<overview|https://github.com/iamalnewkirk/do/blob/master/OVERVIEW.md>, and
+the project L<wiki|https://github.com/iamalnewkirk/do/wiki>.
 
 =cut
 
@@ -868,7 +868,7 @@ If you don't have cpanm, get it! It takes less than a minute, otherwise:
 
 Add C<Do> to the list of dependencies in C<cpanfile>:
 
-  requires "Do" => "1.80"; # 1.80 or newer
+  requires "Do" => "1.86"; # 1.86 or newer
 
 If cpanm doesn't have permission to install modules in the current Perl
 installation, it will automatically set up and install to a local::lib in your
@@ -881,7 +881,7 @@ completely isolated Perl installations.
 
 =head1 CREDITS
 
-Al Newkirk, C<+309>
+Al Newkirk, C<+315>
 
 Anthony Brummett, C<+10>
 
@@ -899,8 +899,9 @@ Al Newkirk, C<awncorp@cpan.org>
 
 Copyright (C) 2011-2019, Al Newkirk, et al.
 
-This is free software; you can redistribute it and/or modify it under the same
-terms as the Perl 5 programming language system itself.
+This is free software; you can redistribute it and/or modify it under the terms
+of the The Apache License, Version 2.0, as elucidated here,
+https://github.com/iamalnewkirk/do/blob/master/LICENSE.
 
 =head1 PROJECT
 
